==> qtjambi-dbus-debuginfo-macos-5.15.17.jar: sources/QtJambiDBus/QDBusAbstractInterfaceBase_shell.h <==
#ifndef QDBUSABSTRACTINTERFACEBASE_SHELL_H
#define QDBUSABSTRACTINTERFACEBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDBus/qdbusabstractinterface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QDBusAbstractInterfaceBase_shell : public QDBusAbstractInterfaceBase, public QtJambiShellInterface
{
public:
    ~QDBusAbstractInterfaceBase_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusAbstractInterfaceBase_access : public QDBusAbstractInterfaceBase
{
};

#endif // QDBUSABSTRACTINTERFACEBASE_SHELL_H

==> qtjambi-dbus-debuginfo-macos-6.5.3.jar: sources/QtJambiDBus/QDBusAbstractInterfaceBase_shell.h <==
#ifndef QDBUSABSTRACTINTERFACEBASE_SHELL_H
#define QDBUSABSTRACTINTERFACEBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDBus/qdbusabstractinterface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QDBusAbstractInterfaceBase_shell : public QDBusAbstractInterfaceBase, public QtJambiShellInterface
{
public:
    ~QDBusAbstractInterfaceBase_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusAbstractInterfaceBase_access : public QDBusAbstractInterfaceBase
{
};

#endif // QDBUSABSTRACTINTERFACEBASE_SHELL_H
